@@ -1,4 +1,4 @@
-export let eventdbFilt = {"plugin": "peek_plugin_eventdb"};
+export let eventdbFilt = { plugin: "peek_plugin_eventdb" };
 export let eventdbTuplePrefix = "peek_plugin_eventdb.";
 
 export let eventdbObservableName = "peek_plugin_eventdb";
