@@ -1,6 +1,5 @@
-import {addTupleType, Tuple} from "@synerty/vortexjs";
-import {eventdbTuplePrefix} from "../PluginNames";
-
+import { addTupleType, Tuple } from "@synerty/vortexjs";
+import { eventdbTuplePrefix } from "../PluginNames";
 
 @addTupleType
 export class AdminStatusTuple extends Tuple {
@@ -12,6 +11,6 @@ export class AdminStatusTuple extends Tuple {
     lastActivity: Date;
 
     constructor() {
-        super(AdminStatusTuple.tupleName)
+        super(AdminStatusTuple.tupleName);
     }
 }
