@@ -1,6 +1,5 @@
-import {addTupleType, Tuple} from "@synerty/vortexjs";
-import {eventdbTuplePrefix} from "../PluginNames";
-
+import { addTupleType, Tuple } from "@synerty/vortexjs";
+import { eventdbTuplePrefix } from "../PluginNames";
 
 @addTupleType
 export class SettingPropertyTuple extends Tuple {
@@ -16,8 +15,7 @@ export class SettingPropertyTuple extends Tuple {
     char_value: string;
     boolean_value: boolean;
 
-
     constructor() {
-        super(SettingPropertyTuple.tupleName)
+        super(SettingPropertyTuple.tupleName);
     }
 }
