@@ -1,8 +1,9 @@
-import {Component, EventEmitter, Input, OnInit, Output} from "@angular/core";
-import {EventDBPropertyTuple} from "@peek/peek_plugin_eventdb/tuples";
-import {PrivateEventDBService} from "@peek/peek_plugin_eventdb/_private/PrivateEventDBService";
-import {ComponentLifecycleEventEmitter} from "@synerty/vortexjs";
-import { BalloonMsgService } from "@synerty/peek-plugin-base-js"
+import { takeUntil } from "rxjs/operators";
+import { Component, EventEmitter, Input, OnInit, Output } from "@angular/core";
+import { EventDBPropertyTuple } from "@peek/peek_plugin_eventdb/tuples";
+import { PrivateEventDBService } from "@peek/peek_plugin_eventdb/_private/PrivateEventDBService";
+import { NgLifeCycleEvents } from "@synerty/vortexjs";
+import { BalloonMsgService } from "@synerty/peek-plugin-base-js";
 
 export interface ColumnI {
     selectedProps: EventDBPropertyTuple[];
@@ -12,11 +13,11 @@ export interface ColumnI {
     selector: "plugin-eventdb-event-column",
     templateUrl: "event-column.component.web.html",
     styleUrls: ["../event-common.component.web.scss"],
-    moduleId: module.id
 })
-export class EventDBColumnComponent extends ComponentLifecycleEventEmitter
-    implements OnInit {
-
+export class EventDBColumnComponent
+    extends NgLifeCycleEvents
+    implements OnInit
+{
     @Input("modelSetKey")
     modelSetKey: string;
 
@@ -25,38 +26,18 @@ export class EventDBColumnComponent extends ComponentLifecycleEventEmitter
 
     isVisible = false;
     isOkLoading = false;
-
-    private propByKey: { [key: string]: EventDBPropertyTuple } = {};
     allProps: EventDBPropertyTuple[] = [];
     selectedProps: EventDBPropertyTuple[] = [];
-
+    private propByKey: { [key: string]: EventDBPropertyTuple } = {};
     private lastRouteParams: string | null = null;
 
-    constructor(private balloonMsg: BalloonMsgService,
-                private eventService: PrivateEventDBService) {
-
+    constructor(
+        private balloonMsg: BalloonMsgService,
+        private eventService: PrivateEventDBService
+    ) {
         super();
     }
 
-    ngOnInit() {
-        this.eventService.propertyTuples(this.modelSetKey)
-            .takeUntil(this.onDestroyEvent)
-            .subscribe((props: EventDBPropertyTuple[]) => {
-                this.allProps = props
-                    .filter(prop => prop.useForDisplay)
-                    .sort((a, b) => a.order - b.order);
-
-                this.propByKey = {};
-                for (let prop of this.allProps) {
-                    this.propByKey[prop.key] = prop;
-                }
-
-                // Give the change detection a chance to run
-                setTimeout(() => this.applyRouteParams(), 100);
-            });
-
-    }
-
     get columnPropKeys(): string[] {
         const result = [];
         for (let prop of this.selectedProps) {
@@ -79,41 +60,23 @@ export class EventDBColumnComponent extends ComponentLifecycleEventEmitter
         setTimeout(() => this.applyRouteParams(), 100);
     }
 
-    private applyRouteParams() {
-        if (this.allProps.length == 0)
-            return;
+    ngOnInit() {
+        this.eventService
+            .propertyTuples(this.modelSetKey)
+            .pipe(takeUntil(this.onDestroyEvent))
+            .subscribe((props: EventDBPropertyTuple[]) => {
+                this.allProps = props
+                    .filter((prop) => prop.useForDisplay)
+                    .sort((a, b) => a.order - b.order);
 
-        if (this.lastRouteParams == null)
-            return;
+                this.propByKey = {};
+                for (let prop of this.allProps) {
+                    this.propByKey[prop.key] = prop;
+                }
 
-        if (this.lastRouteParams.length == 0) {
-            this.selectedProps = this.allProps
-                .filter(prop => prop.displayByDefaultOnDetailView);
-
-        } else {
-            const propKeys = this.lastRouteParams.split(",");
-            this.selectedProps = [];
-
-            for (let propKey of propKeys) {
-                const prop: EventDBPropertyTuple = this.propByKey[propKey];
-                if (prop == null)
-                    continue;
-
-                this.selectedProps.push(prop);
-            }
-        }
-
-        // Clear the route data
-        this.lastRouteParams = null;
-
-        // Update the filter
-        this.updateColumns();
-    }
-
-    private updateColumns() {
-        this.columnChange.emit({
-            selectedProps: this.selectedProps
-        });
+                // Give the change detection a chance to run
+                setTimeout(() => this.applyRouteParams(), 100);
+            });
     }
 
     showModal(): void {
@@ -134,12 +97,47 @@ export class EventDBColumnComponent extends ComponentLifecycleEventEmitter
     resetDefaults(): void {
         this.isOkLoading = true;
 
-        this.selectedProps = this.allProps
-            .filter(prop => prop.displayByDefaultOnDetailView);
+        this.selectedProps = this.allProps.filter(
+            (prop) => prop.displayByDefaultOnDetailView
+        );
     }
 
     onCancelClicked(): void {
         this.selectedProps = [];
         this.isVisible = false;
     }
+
+    private applyRouteParams() {
+        if (this.allProps.length == 0) return;
+
+        if (this.lastRouteParams == null) return;
+
+        if (this.lastRouteParams.length == 0) {
+            this.selectedProps = this.allProps.filter(
+                (prop) => prop.displayByDefaultOnDetailView
+            );
+        } else {
+            const propKeys = this.lastRouteParams.split(",");
+            this.selectedProps = [];
+
+            for (let propKey of propKeys) {
+                const prop: EventDBPropertyTuple = this.propByKey[propKey];
+                if (prop == null) continue;
+
+                this.selectedProps.push(prop);
+            }
+        }
+
+        // Clear the route data
+        this.lastRouteParams = null;
+
+        // Update the filter
+        this.updateColumns();
+    }
+
+    private updateColumns() {
+        this.columnChange.emit({
+            selectedProps: this.selectedProps,
+        });
+    }
 }
