@@ -2,7 +2,7 @@ import { CommonModule } from "@angular/common";
 import { HttpClientModule } from "@angular/common/http";
 import { FormsModule } from "@angular/forms";
 import { NgModule } from "@angular/core";
-import { Routes } from "@angular/router";
+import { RouterModule, Routes } from "@angular/router";
 import { NzDropDownModule } from "ng-zorro-antd/dropdown";
 import { NzTableModule } from "ng-zorro-antd/table";
 import { NzToolTipModule } from "ng-zorro-antd/tooltip";
@@ -20,7 +20,6 @@ import { EventDBPageComponent } from "./event-page-component/event-page.componen
 import { NzDatePickerModule } from "ng-zorro-antd/date-picker";
 import { NzGridModule } from "ng-zorro-antd/grid";
 import { NzSwitchModule } from "ng-zorro-antd/switch";
-import { RouterModule } from "@angular/router";
 
 // Define the child routes for this plugin
 export const pluginRoutes: Routes = [
