@@ -2,11 +2,16 @@ import logging
 from collections import defaultdict
 from typing import List, Optional
 
-from peek_plugin_base.storage.LoadPayloadPgUtil import getTuplesPayloadBlocking, \
-    LoadPayloadTupleResult
-from peek_plugin_eventdb._private.server.controller.EventDBController import \
-    EventDBController
-from peek_plugin_eventdb._private.storage.EventDBModelSetTable import getOrCreateEventDBModelSet
+from peek_plugin_base.storage.LoadPayloadPgUtil import (
+    getTuplesPayloadBlocking,
+    LoadPayloadTupleResult,
+)
+from peek_plugin_eventdb._private.server.controller.EventDBController import (
+    EventDBController,
+)
+from peek_plugin_eventdb._private.storage.EventDBModelSetTable import (
+    getOrCreateEventDBModelSet,
+)
 from peek_plugin_eventdb.server.EventDBReadApiABC import EventDBReadApiABC
 from peek_plugin_eventdb.tuples.EventDBEventTuple import EventDBEventTuple
 from rx.subjects import Subject
@@ -18,7 +23,6 @@ logger = logging.getLogger(__name__)
 
 
 class EventDBReadApi(EventDBReadApiABC):
-
     def __init__(self):
         self._eventdbController = None
         self._dbSessionCreator = None
@@ -26,9 +30,7 @@ class EventDBReadApi(EventDBReadApiABC):
 
         self._newEventsSubject = defaultdict(Subject)
 
-    def setup(self, eventdbController: EventDBController,
-              dbSessionCreator,
-              dbEngine):
+    def setup(self, eventdbController: EventDBController, dbSessionCreator, dbEngine):
         self._eventdbController = eventdbController
         self._dbSessionCreator = dbSessionCreator
         self._dbEngine = dbEngine
