@@ -4,17 +4,18 @@ from typing import List
 from twisted.internet.defer import Deferred, inlineCallbacks
 
 from peek_plugin_eventdb._private.server.EventDBReadApi import EventDBReadApi
-from peek_plugin_eventdb._private.server.controller.EventDBController import \
-    EventDBController
-from peek_plugin_eventdb._private.server.controller.EventDBImportController import \
-    EventDBImportController
+from peek_plugin_eventdb._private.server.controller.EventDBController import (
+    EventDBController,
+)
+from peek_plugin_eventdb._private.server.controller.EventDBImportController import (
+    EventDBImportController,
+)
 from peek_plugin_eventdb.server.EventDBWriteApiABC import EventDBWriteApiABC
 
 logger = logging.getLogger(__name__)
 
 
 class EventDBWriteApi(EventDBWriteApiABC):
-
     def __init__(self):
         self._queueController = None
         self._eventdbController = None
@@ -23,11 +24,14 @@ class EventDBWriteApi(EventDBWriteApiABC):
         self._dbSessionCreator = None
         self._dbEngine = None
 
-    def setup(self, eventdbController: EventDBController,
-              eventdbImportController: EventDBImportController,
-              readApi: EventDBReadApi,
-              dbSessionCreator,
-              dbEngine):
+    def setup(
+        self,
+        eventdbController: EventDBController,
+        eventdbImportController: EventDBImportController,
+        readApi: EventDBReadApi,
+        dbSessionCreator,
+        dbEngine,
+    ):
         self._eventdbController = eventdbController
         self._eventdbImportController = eventdbImportController
         self._readApi = readApi
@@ -42,8 +46,9 @@ class EventDBWriteApi(EventDBWriteApiABC):
         if not eventsEncodedPayload:
             return
 
-        yield self._eventdbImportController.importEvents(modelSetKey,
-                                                         eventsEncodedPayload)
+        yield self._eventdbImportController.importEvents(
+            modelSetKey, eventsEncodedPayload
+        )
 
     @inlineCallbacks
     def removeEvents(self, modelSetKey: str, eventKeys: List[str]) -> Deferred:
@@ -53,19 +58,23 @@ class EventDBWriteApi(EventDBWriteApiABC):
         yield self._eventdbImportController.deleteEvents(modelSetKey, eventKeys)
 
     @inlineCallbacks
-    def updateAlarmFlags(self, modelSetKey: str, eventKeys: List[str],
-                         alarmFlag: bool) -> Deferred:
+    def updateAlarmFlags(
+        self, modelSetKey: str, eventKeys: List[str], alarmFlag: bool
+    ) -> Deferred:
         if not eventKeys:
             return
 
-        yield self._eventdbImportController.updateAlarmFlags(modelSetKey,
-                                                             eventKeys, alarmFlag)
+        yield self._eventdbImportController.updateAlarmFlags(
+            modelSetKey, eventKeys, alarmFlag
+        )
 
     @inlineCallbacks
-    def replaceProperties(self, modelSetKey: str,
-                          propertiesEncodedPayload: str) -> Deferred:
+    def replaceProperties(
+        self, modelSetKey: str, propertiesEncodedPayload: str
+    ) -> Deferred:
         if not propertiesEncodedPayload:
             return
 
-        yield self._eventdbImportController.replaceProperties(modelSetKey,
-                                                              propertiesEncodedPayload)
+        yield self._eventdbImportController.replaceProperties(
+            modelSetKey, propertiesEncodedPayload
+        )
