@@ -6,8 +6,9 @@ from vortex.Payload import Payload
 from vortex.TupleSelector import TupleSelector
 from vortex.handler.TupleDataObservableHandler import TuplesProviderABC
 
-from peek_plugin_eventdb._private.server.controller.AdminStatusController import \
-    AdminStatusController
+from peek_plugin_eventdb._private.server.controller.AdminStatusController import (
+    AdminStatusController,
+)
 
 logger = logging.getLogger(__name__)
 
@@ -17,8 +18,9 @@ class AdminStatusTupleProvider(TuplesProviderABC):
         self._statusController = statusController
 
     @inlineCallbacks
-    def makeVortexMsg(self, filt: dict,
-                      tupleSelector: TupleSelector) -> Union[Deferred, bytes]:
+    def makeVortexMsg(
+        self, filt: dict, tupleSelector: TupleSelector
+    ) -> Union[Deferred, bytes]:
         tuples = [self._statusController.status]
 
         payloadEnvelope = yield Payload(filt, tuples=tuples).makePayloadEnvelopeDefer()
