@@ -1,8 +1,8 @@
-import {Observable} from "rxjs";
-import {EventDBPropertyCriteriaTuple} from "./tuples/EventDBPropertyCriteriaTuple";
-import {EventDBEventTuple} from "./tuples/EventDBEventTuple";
-import {EventDBPropertyTuple} from "./tuples/EventDBPropertyTuple";
-import {TupleSelector} from "@synerty/vortexjs";
+import { Observable } from "rxjs";
+import { EventDBPropertyCriteriaTuple } from "./tuples/EventDBPropertyCriteriaTuple";
+import { EventDBEventTuple } from "./tuples/EventDBEventTuple";
+import { EventDBPropertyTuple } from "./tuples/EventDBPropertyTuple";
+import { TupleSelector } from "@synerty/vortexjs";
 
 export interface EventDateTimeRangeI {
     oldestDateTime?: Date | null;
@@ -16,14 +16,15 @@ export interface EventDateTimeRangeI {
  *
  */
 export abstract class EventDBService {
-
     /** Property Tuples
      *
      * Return an observable that fires with a list of property tuples.
      *
      * @param modelSetKey: The model to observe the data from.
      */
-    abstract propertyTuples(modelSetKey: string): Observable<EventDBPropertyTuple[]> | null;
+    abstract propertyTuples(
+        modelSetKey: string
+    ): Observable<EventDBPropertyTuple[]> | null;
 
     /** Event Tuples
      *
@@ -37,7 +38,8 @@ export abstract class EventDBService {
         modelSetKey: string,
         dateTimeRange: EventDateTimeRangeI,
         criteria: EventDBPropertyCriteriaTuple[],
-        alarmsOnly: boolean): Observable<EventDBEventTuple[]> ;
+        alarmsOnly: boolean
+    ): Observable<EventDBEventTuple[]>;
 
     /** Event Tuples Selector
      *
@@ -56,8 +58,6 @@ export abstract class EventDBService {
         modelSetKey: string,
         dateTimeRange: EventDateTimeRangeI,
         criteria: EventDBPropertyCriteriaTuple[],
-        alarmsOnly: boolean): TupleSelector ;
+        alarmsOnly: boolean
+    ): TupleSelector;
 }
-
-
-
