@@ -1,6 +1,5 @@
-import {addTupleType, Tuple} from "@synerty/vortexjs";
-import {eventdbTuplePrefix} from "../_private/PluginNames";
-
+import { addTupleType, Tuple } from "@synerty/vortexjs";
+import { eventdbTuplePrefix } from "../_private/PluginNames";
 
 @addTupleType
 export class EventDBEventTuple extends Tuple {
@@ -19,6 +18,6 @@ export class EventDBEventTuple extends Tuple {
     value: any;
 
     constructor() {
-        super(EventDBEventTuple.tupleName)
+        super(EventDBEventTuple.tupleName);
     }
 }
