@@ -1,21 +1,21 @@
-import {addTupleType, Tuple} from "@synerty/vortexjs";
-import {eventdbTuplePrefix} from "../_private/PluginNames";
-
+import { addTupleType, Tuple } from "@synerty/vortexjs";
+import { eventdbTuplePrefix } from "../_private/PluginNames";
 
 /** Event DB Property Value Tuple
-
+ 
  This tuple is an option that the user can select for each property.
-
+ 
  For example:
-
+ 
  Property = Alarm Class
  Property Value = Class 1
  Property Value = Class 2
-
+ 
  */
 @addTupleType
 export class EventDBPropertyValueTuple extends Tuple {
-    public static readonly tupleName = eventdbTuplePrefix + "EventDBPropertyValueTuple";
+    public static readonly tupleName =
+        eventdbTuplePrefix + "EventDBPropertyValueTuple";
 
     // name: The name of this property value that is displayed to the user.
     name: string;
@@ -33,6 +33,6 @@ export class EventDBPropertyValueTuple extends Tuple {
     comment: string;
 
     constructor() {
-        super(EventDBPropertyValueTuple.tupleName)
+        super(EventDBPropertyValueTuple.tupleName);
     }
 }
